@@ -258,6 +258,9 @@ gboolean CDStat(DiscInfo *disc,gboolean read_toc)
     cdsc.cdsc_absaddr.msf.frame;
 
   switch(cdsc.cdsc_audiostatus) {
+    case CDROM_AUDIO_INVALID:
+      disc->disc_mode = CDAUDIO_NOSTATUS;
+      break;
   case CDROM_AUDIO_PLAY:
     disc->disc_mode=CDAUDIO_PLAYING;
     break;
