@@ -28,6 +28,7 @@
 #include "cddev.h"
 #include "discedit.h"
 #include "dialog.h"
+#include "tray.h"
 #include "rip.h"
 #include "grip_id3.h"
 
@@ -288,7 +289,6 @@ void MakeTrackPage(GripInfo *ginfo)
   GtkWidget *trackpage;
   GtkWidget *vbox;
   GripGUI *uinfo;
-  GtkRequisition sizereq;
   GtkWidget *scroll;
   GtkTreeViewColumn *column;
   GtkCellRenderer *renderer;
@@ -396,10 +396,6 @@ void MakeTrackPage(GripInfo *ginfo)
 
   gtk_widget_show(uinfo->track_list);
 
-  gtk_widget_size_request(uinfo->track_list,&sizereq);
-  //  gtk_widget_set_usize(trackpage,sizereq.width+30,-1);
-  gtk_widget_set_usize(trackpage,500,-1);
-
   gtk_container_add(GTK_CONTAINER(trackpage),vbox);
   gtk_widget_show(vbox);
 }
@@ -488,10 +484,11 @@ gboolean TrackIsChecked(GripGUI *uinfo,int track)
 
   path=gtk_tree_path_new_from_indices(track,-1);
 
-  gtk_tree_model_get_iter(GTK_TREE_MODEL(uinfo->track_list_store),&iter,path);
+  checked = gtk_tree_model_get_iter(GTK_TREE_MODEL(uinfo->track_list_store),&iter,path);
 
-  gtk_tree_model_get(GTK_TREE_MODEL(uinfo->track_list_store),
-		     &iter,TRACKLIST_RIP_COL,&checked,-1);
+  if (checked)
+    gtk_tree_model_get(GTK_TREE_MODEL(uinfo->track_list_store),
+		       &iter,TRACKLIST_RIP_COL,&checked,-1);
 
   return checked;
 }
@@ -1790,8 +1787,8 @@ void UpdateDisplay(GripInfo *ginfo)
       
       SetCurrentTrack(ginfo,-1);
     }
-
-    gdk_window_set_icon_name(uinfo->app->window,icon_buf);
+    if(uinfo->app->window)
+      gdk_window_set_icon_name(uinfo->app->window,icon_buf);
   }
 }
 
