@@ -188,8 +188,8 @@ GtkWidget *MakeNumEntry(GtkWidget **entry,int *var,char *name,int len)
   gtk_box_pack_start(GTK_BOX(hbox),label,FALSE,FALSE,0);
   gtk_widget_show(label);
 
-  widget=gtk_entry_new_with_max_length(len);
-  gtk_widget_set_usize(widget,len*8+5,0);
+  widget=gtk_entry_new();
+  gtk_entry_set_max_length(GTK_ENTRY(widget),len);
 
   if(var) {
     sprintf(buf,"%d",*var);
@@ -229,22 +229,6 @@ GtkWidget *MakeDoubleEntry(GtkWidget **entry,gdouble *var,char *name)
 
   widget=gtk_spin_button_new(GTK_ADJUSTMENT(adj),0.1,3);
 
-
-
-  /***************************
-
-
-
-  gtk_widget_set_usize(widget,
-		       gdk_string_width((widget)->style->font,
-					"0.000")+25,0);
-
-
-  ************************/
-
-
-
-
   if(var) {
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(widget),*var);
     gtk_signal_connect(GTK_OBJECT(widget),"changed",
