@@ -65,7 +65,9 @@ void DoSaveConfig(GripInfo *ginfo);
 {"mp3cmdline",CFG_ENTRY_STRING,256,ginfo->mp3cmdline},\
 {"dbserver",CFG_ENTRY_STRING,256,ginfo->dbserver.name},\
 {"ripfileformat",CFG_ENTRY_STRING,256,ginfo->ripfileformat},\
+{"ripfileformat_multi",CFG_ENTRY_STRING,256,ginfo->ripfileformat_multi},\
 {"mp3fileformat",CFG_ENTRY_STRING,256,ginfo->mp3fileformat},\
+{"mp3fileformat_multi",CFG_ENTRY_STRING,256,ginfo->mp3fileformat_multi},\
 {"mp3extension",CFG_ENTRY_STRING,10,ginfo->mp3extension},\
 {"m3ufileformat",CFG_ENTRY_STRING,256,ginfo->m3ufileformat},\
 {"delete_wavs",CFG_ENTRY_BOOL,0,&ginfo->delete_wavs},\
@@ -114,6 +116,7 @@ void DoSaveConfig(GripInfo *ginfo);
 {"automatic_reshuffle",CFG_ENTRY_BOOL,0,&ginfo->automatic_reshuffle},\
 {"no_lower_case",CFG_ENTRY_BOOL,0,&ginfo->sprefs.no_lower_case},\
 {"no_underscore",CFG_ENTRY_BOOL,0,&ginfo->sprefs.no_underscore},\
+{"non_posix_m3u_directory_paths",CFG_ENTRY_BOOL,0,&ginfo->sprefs.non_posix_m3u_directory_paths},\
 {"allow_high_bits",CFG_ENTRY_BOOL,0,&ginfo->sprefs.allow_high_bits},\
 {"escape",CFG_ENTRY_BOOL,0,&ginfo->sprefs.escape},\
 {"allow_these_chars",CFG_ENTRY_STRING,256,ginfo->sprefs.allow_these_chars},\
@@ -132,7 +135,8 @@ void DoSaveConfig(GripInfo *ginfo);
 {"vol_vis",CFG_ENTRY_BOOL,0,&uinfo->volvis},\
 {"track_edit_vis",CFG_ENTRY_BOOL,0,&uinfo->track_edit_visible},\
 {"track_prog_vis",CFG_ENTRY_BOOL,0,&uinfo->track_prog_visible},\
-{"volume",CFG_ENTRY_INT,0,&ginfo->volume},
+{"volume",CFG_ENTRY_INT,0,&ginfo->volume},\
+{"execute_after_encode_cmd",CFG_ENTRY_STRING,256,ginfo->execute_after_encode_cmd},
 
 #define CDPAR_CFG_ENTRIES \
 {"disable_paranoia",CFG_ENTRY_BOOL,0,&ginfo->disable_paranoia},\
@@ -319,10 +323,10 @@ GtkWidget *GripNew(const gchar* geometry,char *device,char *scsi_device,
     sscanf(VERSION,"%d.%d.%d",&major,&minor,&point);
 
     /* Check if we have a dev release */
-    if(minor%2) {
+    /*if(minor%2) {
       gnome_app_warning((GnomeApp *)ginfo->gui_info.app,
                         _("This is a development version of Grip. If you encounter problems, you are encouraged to revert to the latest stable version."));
-    }
+    }*/
   }
 
   g_signal_connect(app, "window-state-event", G_CALLBACK(AppWindowStateCB), ginfo);
@@ -541,7 +545,7 @@ void MakeAboutPage(GripGUI *uinfo)
   GtkWidget *logo;
   GtkWidget *ebox;
   GtkWidget *button;
-  char versionbuf[20];
+  gchar *versionbuf;
 
   aboutpage=MakeNewPage(uinfo->notebook,_("About"));
 
@@ -562,13 +566,15 @@ void MakeAboutPage(GripGUI *uinfo)
 
   vbox2=gtk_vbox_new(TRUE,0);
 
-  sprintf(versionbuf,_("Version %s"),VERSION);
+  versionbuf = g_strdup_printf(_("Version %s"),VERSION);
   label=gtk_label_new(versionbuf);
+  g_free(versionbuf);
+
   gtk_widget_set_style(label,uinfo->style_wb);
   gtk_box_pack_start(GTK_BOX(vbox2),label,FALSE,FALSE,0);
   gtk_widget_show(label);
 
-  label=gtk_label_new("Copyright 1998-2005, Mike Oliphant");
+  label=gtk_label_new("Copyright\n1998-2005, Mike Oliphant\n2016-2017, Johnny A. Solbu");
   gtk_widget_set_style(label,uinfo->style_wb);
   gtk_box_pack_start(GTK_BOX(vbox2),label,FALSE,FALSE,0);
   gtk_widget_show(label);
@@ -582,7 +588,7 @@ void MakeAboutPage(GripGUI *uinfo)
 
   hbox=gtk_hbox_new(TRUE,0);
 
-  button=gtk_button_new_with_label("http://www.nostatic.org/grip");
+  button=gtk_button_new_with_label("https://sourceforge.net/projects/grip/");
   gtk_widget_set_style(button,uinfo->style_dark_grey);
   gtk_widget_set_style(GTK_BIN(button)->child,
 		       uinfo->style_dark_grey);
@@ -625,7 +631,7 @@ static void MakeStyles(GripGUI *uinfo)
 
 static void Homepage(void)
 {
-  system("gnome-moz-remote http://www.nostatic.org/grip");
+  system("xdg-open https://sourceforge.net/projects/grip/");
 }
 
 static void LoadImages(GripGUI *uinfo)
@@ -862,7 +868,8 @@ static void DoLoadConfig(GripInfo *ginfo)
   ginfo->using_builtin_cdp=FALSE;
 #endif
   ginfo->in_rip_thread=FALSE;
-  strcpy(ginfo->ripfileformat,"~/mp3/%A/%d/%n.wav");
+  strcpy(ginfo->ripfileformat,"~/ogg/%A/%d/%n.wav");
+  strcpy(ginfo->ripfileformat_multi,"~/ogg/%A/%d/%a_%n.wav");
 #ifdef __linux__
   FindExeInPath("cdparanoia", ginfo->ripexename, sizeof(ginfo->ripexename));
   strcpy(ginfo->ripcmdline,"-d %c %t:[.%s]-%t:[.%e] %w");
@@ -885,19 +892,20 @@ static void DoLoadConfig(GripInfo *ginfo)
   ginfo->stop_between_tracks=FALSE;
   *ginfo->wav_filter_cmd='\0';
   *ginfo->disc_filter_cmd='\0';
-  ginfo->selected_encoder=1;
-  strcpy(ginfo->mp3cmdline,"-h -b %b %w %m");
-  FindExeInPath("lame", ginfo->mp3exename, sizeof(ginfo->mp3exename));
-  strcpy(ginfo->mp3fileformat,"~/mp3/%A/%d/%n.%x");
-  strcpy(ginfo->mp3extension,"mp3");
+  ginfo->selected_encoder=6;
+  strcpy(ginfo->mp3cmdline,"-o %m -a %a -l %d -t %n -b %b %w -N %t -G %G -d %y");
+  FindExeInPath("oggenc", ginfo->mp3exename, sizeof(ginfo->mp3exename));
+  strcpy(ginfo->mp3fileformat,"~/ogg/%A/%d/%t_%n.%x");
+  strcpy(ginfo->mp3fileformat_multi,"~/ogg/%A/%d/%t_%a_%n.%x");
+  strcpy(ginfo->mp3extension,"ogg");
   ginfo->mp3nice=0;
   *ginfo->mp3_filter_cmd='\0';
   ginfo->delete_wavs=TRUE;
   ginfo->add_to_db=FALSE;
   ginfo->add_m3u=TRUE;
   ginfo->rel_m3u=TRUE;
-  strcpy(ginfo->m3ufileformat,"~/mp3/%A-%d.m3u");
-  ginfo->kbits_per_sec=128;
+  strcpy(ginfo->m3ufileformat,"~/ogg/%A-%d.m3u");
+  ginfo->kbits_per_sec=192;
   ginfo->edit_num_cpu=1;
   ginfo->doid3=TRUE;
   ginfo->doid3=FALSE;
@@ -908,6 +916,7 @@ static void DoLoadConfig(GripInfo *ginfo)
   ginfo->sprefs.allow_high_bits=FALSE;
   ginfo->sprefs.escape=FALSE;
   ginfo->sprefs.no_underscore=FALSE;
+  ginfo->sprefs.non_posix_m3u_directory_paths=FALSE;
   *ginfo->sprefs.allow_these_chars='\0';
   ginfo->show_tray_icon=TRUE;
 
@@ -944,11 +953,21 @@ static void DoLoadConfig(GripInfo *ginfo)
     strcat(filename,ginfo->mp3fileformat);
     strcpy(ginfo->mp3fileformat,filename);
 
+    strcpy(filename,outputdir);
+    MakePath(filename);
+    strcat(filename,ginfo->mp3fileformat_multi);
+    strcpy(ginfo->mp3fileformat_multi,filename);
+
     strcpy(filename,outputdir);
     MakePath(filename);
     strcat(filename,ginfo->ripfileformat);
     strcpy(ginfo->ripfileformat,filename);
 
+    strcpy(filename,outputdir);
+    MakePath(filename);
+    strcat(filename,ginfo->ripfileformat_multi);
+    strcpy(ginfo->ripfileformat_multi,filename);
+
     *outputdir='\0';
   }
 #endif
