@@ -37,7 +37,7 @@
 #define CDPAR
 #endif
 
-#define WINWIDTH 400
+#define WINWIDTH 600
 #define WINHEIGHT 450
 
 #define WINHEIGHTEDIT 600
@@ -49,7 +49,7 @@
 
 #define RRand(range) (random()%(range))
 
-#if defined(__linux__) || defined(__FreeBSD__) || defined(__NetBSD__) || defined(__osf__)  /* __osf__ ?? */
+#if defined(__linux__) || defined(__FreeBSD__) || defined(__GLIBC__) || defined(__NetBSD__) || defined(__osf__)  /* __osf__ ?? */
 
 #define MAILER "/usr/sbin/sendmail -i -t"
 
@@ -296,6 +296,7 @@ typedef struct _grip_info {
 #endif
   char ripexename[256];
   char ripfileformat[256];
+  char ripfileformat_multi[256];
   char ripcmdline[256];
   int ripnice;
   int max_wavs;
@@ -312,6 +313,7 @@ typedef struct _grip_info {
   char mp3cmdline[256];
   char mp3extension[10];
   char mp3fileformat[256];
+  char mp3fileformat_multi[256];
   char mp3exename[256];
   gboolean delete_wavs;
   gboolean add_to_db;
@@ -322,6 +324,7 @@ typedef struct _grip_info {
   int edit_num_cpu;
   int mp3nice;
   char mp3_filter_cmd[256];
+  char execute_after_encode_cmd[256];
   gboolean doid3;
   gboolean doid3v2;
   gboolean tag_mp3_only;
