@@ -48,7 +48,7 @@ static Ripper ripper_defaults[]={
 };
 
 static MP3Encoder encoder_defaults[]={{"bladeenc","-%b -QUIT %w %m","mp3"},
-				      {"lame","-h -b %b %w %m","mp3"},
+				      {"lame","-h --add-id3v2 --tt \"%n\" --ta \"%a\" --tl \"%d\" --ty \"%y\" --tn \"%t\" --tg \"%G\" -b %b %w %m","mp3"},
 				      {"l3enc","-br %b %w %m","mp3"},
 				      {"xingmp3enc","-B %b -Q %w","mp3"},
 				      {"mp3encode","-p 2 -l 3 -b %b %w %m",
@@ -57,7 +57,7 @@ static MP3Encoder encoder_defaults[]={{"bladeenc","-%b -QUIT %w %m","mp3"},
 				      {"oggenc",
 				       "-o %m -a %a -l %d -t %n -b %b -N %t -G %G -d %y %w",
 				       "ogg"},
-				      {"flac","-V -o %m %w","flac"},
+				      {"flac","--best --replay-gain -T title=\"%n\" -T artist=\"%a\" -T album=\"%d\" -T date=\"%y\" -T tracknumber=\"%t\" -T genre=\"%G\"  -o %m %w","flac"},
 				      {"other","",""},
 				      {"",""}
 };
@@ -272,6 +272,11 @@ void MakeConfigPage(GripInfo *ginfo)
   gtk_box_pack_start(GTK_BOX(vbox),entry,FALSE,FALSE,0);
   gtk_widget_show(entry);
 
+  entry=MakeStrEntry(NULL,ginfo->ripfileformat_multi,
+             _("Rip file format (Multi-artist)"),255,TRUE);
+  gtk_box_pack_start(GTK_BOX(vbox),entry,FALSE,FALSE,0);
+  gtk_widget_show(entry);
+
   entry=MakeStrEntry(NULL,ginfo->force_scsi,_("Generic SCSI device"),
 		     255,TRUE);
   gtk_box_pack_start(GTK_BOX(vbox),entry,FALSE,FALSE,0);
@@ -420,12 +425,18 @@ void MakeConfigPage(GripInfo *ginfo)
   gtk_widget_show(entry);
 
   entry=MakeStrEntry(&(uinfo->mp3extension_entry),ginfo->mp3extension,
-		     _("Encode file extension"),
+		     _("Encoder file extension"),
 		     10,TRUE);
   gtk_box_pack_start(GTK_BOX(vbox),entry,FALSE,FALSE,0);
   gtk_widget_show(entry);
   
-  entry=MakeStrEntry(NULL,ginfo->mp3fileformat,_("Encode file format"),
+  entry=MakeStrEntry(NULL,ginfo->mp3fileformat,_("Encoder file format"),
+		     255,TRUE);
+  gtk_box_pack_start(GTK_BOX(vbox),entry,FALSE,FALSE,0);
+  gtk_widget_show(entry);
+
+  entry=MakeStrEntry(NULL,ginfo->mp3fileformat_multi,
+             _("Encode file format (Multi-artist)"),
 		     255,TRUE);
   gtk_box_pack_start(GTK_BOX(vbox),entry,FALSE,FALSE,0);
   gtk_widget_show(entry);
@@ -474,11 +485,16 @@ void MakeConfigPage(GripInfo *ginfo)
   gtk_box_pack_start(GTK_BOX(vbox),entry,FALSE,FALSE,0);
   gtk_widget_show(entry);
   
-  entry=MakeNumEntry(NULL,&ginfo->mp3nice,_("Encode 'nice' value"),3);
+  entry=MakeNumEntry(NULL,&ginfo->mp3nice,_("Encoder 'nice' value"),3);
   gtk_box_pack_start(GTK_BOX(vbox),entry,FALSE,FALSE,0);
   gtk_widget_show(entry);
   
-  entry=MakeStrEntry(NULL,ginfo->mp3_filter_cmd,_("Encode filter command"),
+  entry=MakeStrEntry(NULL,ginfo->mp3_filter_cmd,_("Encoder filter command"),
+		     255,TRUE);
+  gtk_box_pack_start(GTK_BOX(vbox),entry,FALSE,FALSE,0);
+  gtk_widget_show(entry);
+  
+  entry=MakeStrEntry(NULL,ginfo->execute_after_encode_cmd,_("Execute command after encode"),
 		     255,TRUE);
   gtk_box_pack_start(GTK_BOX(vbox),entry,FALSE,FALSE,0);
   gtk_widget_show(entry);
@@ -697,6 +713,11 @@ void MakeConfigPage(GripInfo *ginfo)
   gtk_box_pack_start(GTK_BOX(vbox),check,FALSE,FALSE,0);
   gtk_widget_show(check);
 
+  check=MakeCheckButton(NULL,&ginfo->sprefs.non_posix_m3u_directory_paths,
+			_("Write m3u files using non-posix compliant '\\'s"));
+  gtk_box_pack_start(GTK_BOX(vbox),check,FALSE,FALSE,0);
+  gtk_widget_show(check);
+
   entry=MakeStrEntry(NULL,ginfo->sprefs.allow_these_chars,
 		     _("Characters to not strip\nin filenames"),255,TRUE);
   gtk_box_pack_start(GTK_BOX(vbox),entry,FALSE,FALSE,0);
@@ -791,7 +812,7 @@ gboolean LoadRipperConfig(GripInfo *ginfo,int ripcfg)
   };
 
 #ifdef CDPAR
-  if(ripcfg==0) return;
+  if(ripcfg==0) return 0;
 #endif
 
   sprintf(buf,"%s/%s-%s",getenv("HOME"),ginfo->config_filename,
