@@ -310,7 +310,7 @@ void TranslateAndLaunch(char *cmd,char *(*trans_func)(char,void *,gboolean *),
   if(pid==0) {
     if(close_func) close_func(close_user_data);
 
-    execv(args[0]->str,char_args);
+    execvp(args[0]->str,char_args);
     
     Debug(_("Exec failed\n"));
     _exit(0);
