@@ -342,6 +342,7 @@ static void DBScan(GtkWidget *widget,gpointer data)
   int track;
   EncodeTrack enc_track;
   GString *str;
+  char *format;
 
   ginfo=(GripInfo *)data;
 
@@ -351,8 +352,11 @@ static void DBScan(GtkWidget *widget,gpointer data)
     FillInTrackInfo(ginfo,track,&enc_track);
     
     str=g_string_new(NULL);
-    
-    TranslateString(ginfo->mp3fileformat,str,TranslateSwitch,
+
+    format = (ginfo->ddata.data_multi_artist)
+                ? ginfo->mp3fileformat_multi
+                : ginfo->mp3fileformat;
+    TranslateString(format,str,TranslateSwitch,
 		    &enc_track,TRUE,&(ginfo->sprefs));
     
     g_snprintf(enc_track.mp3_filename,256,"%s",str->str);
@@ -575,7 +579,10 @@ static gboolean AddM3U(GripInfo *ginfo)
   char *relnam;
   GString *str;
   char *conv_str;
+  char *non_posix_name_filter;
+  char line_terminator[3];
   gsize rb,wb;
+  char *format;
 
   if(!ginfo->have_disc) return FALSE;
   
@@ -610,7 +617,10 @@ static gboolean AddM3U(GripInfo *ginfo)
       g_string_truncate(str,0);
 
       FillInTrackInfo(ginfo,i,&enc_track);
-      TranslateString(ginfo->mp3fileformat,str,TranslateSwitch,
+      format = (ginfo->ddata.data_multi_artist)
+                ? ginfo->mp3fileformat_multi
+                : ginfo->mp3fileformat;
+      TranslateString(format,str,TranslateSwitch,
 		      &enc_track,TRUE,&(ginfo->sprefs));
 
       conv_str=g_filename_from_utf8(str->str,strlen(str->str),&rb,&wb,NULL);
@@ -618,15 +628,39 @@ static gboolean AddM3U(GripInfo *ginfo)
       if(!conv_str)
     	conv_str=g_strdup(str->str);
 
+      g_snprintf(tmp,PATH_MAX,"%s",conv_str);
+      relnam=MakeRelative(tmp,m3unam);
+
+      if(ginfo->sprefs.non_posix_m3u_directory_paths) {
+        sprintf (line_terminator, "\r\n");
+
+
+	for (non_posix_name_filter=conv_str; *non_posix_name_filter; non_posix_name_filter++) {
+			if (*non_posix_name_filter == '/'){
+				*non_posix_name_filter = '\\';
+			}
+	}
+	for (non_posix_name_filter=relnam; *non_posix_name_filter; non_posix_name_filter++) {
+			if (*non_posix_name_filter == '/'){
+				*non_posix_name_filter = '\\';
+			}
+	}
+      }
+      else
+      {
+	sprintf (line_terminator, "\n");
+
+      }
+
       if(ginfo->rel_m3u) {
-	g_snprintf(tmp,PATH_MAX,"%s",conv_str);
-	relnam=MakeRelative(tmp,m3unam);
-	fprintf(fp,"%s\n",relnam);
+
+
+	fprintf(fp,"%s%s",relnam, line_terminator);
       }
       else 
-	fprintf(fp,"%s\n",conv_str);
+	fprintf(fp,"%s%s",conv_str, line_terminator);
       g_free(conv_str);
-    }
+     }
   }
 
   g_string_free(str,TRUE);
@@ -636,6 +670,31 @@ static gboolean AddM3U(GripInfo *ginfo)
   return TRUE;
 }
 
+void RemoveM3U(GripInfo *ginfo)
+{
+  FILE *fp;
+  EncodeTrack enc_track;
+  char testchar;
+  GString *str;
+
+  if (!ginfo->have_disc) return;
+
+  str=g_string_new(NULL);
+
+  FillInTrackInfo(ginfo, 0, &enc_track);
+  TranslateString(ginfo->m3ufileformat, str, TranslateSwitch,
+		  &enc_track, TRUE, &(ginfo->sprefs));
+
+  fp=fopen(str->str, "r");
+  if (fp==NULL)
+    return;
+  testchar = fgetc(fp);
+  fclose(fp);
+  if (testchar == EOF)
+    remove(str->str);
+  return;
+}
+
 void KillRip(GtkWidget *widget,gpointer data)
 {
   GripInfo *ginfo;
@@ -808,7 +867,7 @@ void UpdateRipProgress(GripInfo *ginfo)
     gtk_progress_bar_update(GTK_PROGRESS_BAR(uinfo->ripprogbar),percent);
 
     now = time(NULL);
-    elapsed = (gfloat)now - (gfloat)ginfo->rip_started;
+    elapsed = (gfloat)(now - ginfo->rip_started);
 
     /* 1x is 44100*2*2 = 176400 bytes/sec */
     if(elapsed < 0.1f) /* 1/10 sec. */
@@ -944,7 +1003,7 @@ void UpdateRipProgress(GripInfo *ginfo)
 			      percent);
        
       now = time(NULL);
-      elapsed = (gfloat)now - (gfloat)ginfo->mp3_started[mycpu];
+      elapsed = (gfloat)(now - ginfo->mp3_started[mycpu]);
 
       if(elapsed < 0.1f) /* 1/10 sec. */
 	speed=0.0f;
@@ -1005,7 +1064,9 @@ void UpdateRipProgress(GripInfo *ginfo)
 	    unlink(ginfo->rip_delete_file[mycpu]);
 	  }
 
-          if(ginfo->doid3 || ginfo->doid3v2)
+	  if((ginfo->doid3 || ginfo->doid3v2) &&
+	     (strstr(ginfo->mp3file[mycpu],".mp3") ||
+	      strstr(ginfo->mp3file[mycpu],".MP3")))
 	    ID3Add(ginfo,ginfo->mp3file[mycpu],
 		   ginfo->encoded_track[mycpu]);
 
@@ -1023,6 +1084,13 @@ void UpdateRipProgress(GripInfo *ginfo)
 	    else RipIsFinished(ginfo,FALSE);
           }
 
+	  /* Check if last encode finished */
+	  if(*ginfo->execute_after_encode_cmd&&!ginfo->rip_partial&&
+	     !ginfo->ripping&&!ginfo->encode_list)
+	    TranslateAndLaunch(ginfo->execute_after_encode_cmd,TranslateSwitch,
+			       ginfo->encoded_track[mycpu],FALSE,
+			       &(ginfo->sprefs),CloseStuff,(void *)ginfo);
+
 	  g_free(ginfo->encoded_track[mycpu]);
          
 	  if(!ginfo->rip_partial&&ginfo->encode_list) {
@@ -1080,7 +1148,17 @@ static void RipIsFinished(GripInfo *ginfo,gboolean aborted)
   
 #ifdef CDPAR
     if(ginfo->using_builtin_cdp && ginfo->calc_gain) {
+      GList *plist;
+
       ginfo->disc_gain_adjustment=GetAlbumGain();
+
+      /* Apply disc gain to all tracks on pending list */
+      for(plist = g_list_first(ginfo->pending_list); plist != NULL;
+                               plist = g_list_next(plist)) {
+        EncodeTrack *enc_track = (EncodeTrack *) plist->data;
+        enc_track->disc_gain_adjustment = ginfo->disc_gain_adjustment;
+      }
+
     }
 #endif
   
@@ -1147,6 +1225,10 @@ char *TranslateSwitch(char switch_char,void *data,gboolean *munge)
     g_snprintf(res,PATH_MAX,"%02d",enc_track->track_num+1);
     *munge=FALSE;
     break;
+  case 'N':
+    g_snprintf(res,PATH_MAX,"%02d",enc_track->ginfo->prog_totaltracks);
+    *munge=FALSE;
+    break;
   case 's':
     g_snprintf(res,PATH_MAX,"%d",enc_track->ginfo->start_sector);
     *munge=FALSE;
@@ -1208,6 +1290,11 @@ char *TranslateSwitch(char switch_char,void *data,gboolean *munge)
     g_snprintf(res,PATH_MAX,"%s",enc_track->ginfo->mp3extension);
     *munge=FALSE;
     break;
+	case 'I':
+		if(*(enc_track->disc_artist))
+			g_snprintf(res,2,"%s",enc_track->disc_artist);
+		else strncpy(res,_("NoArtist"),2);        
+		break;
   default:
     *res='\0';
     break;
@@ -1341,7 +1428,10 @@ static void RipWholeCD(gint reply,gpointer data)
   int track;
   GripInfo *ginfo;
 
-  if(reply) return;
+  if(reply) {
+    RemoveM3U((GripInfo *) data);
+    return;
+  }
 
   Debug(_("Ripping whole CD\n"));
 
@@ -1379,6 +1469,7 @@ static gboolean RipNextTrack(GripInfo *ginfo)
   char *conv_str, *utf8_ripfile;
   gsize rb,wb;
   const char *charset;
+  char *format;
 
   uinfo=&(ginfo->gui_info);
 
@@ -1427,7 +1518,10 @@ static gboolean RipNextTrack(GripInfo *ginfo)
     str=g_string_new(NULL);
     FillInTrackInfo(ginfo,ginfo->rip_track,&enc_track);
 
-    TranslateString(ginfo->ripfileformat,str,TranslateSwitch,
+    format = (ginfo->ddata.data_multi_artist)
+                ? ginfo->ripfileformat_multi
+                : ginfo->ripfileformat;
+    TranslateString(format,str,TranslateSwitch,
 		    &enc_track,TRUE,&(ginfo->sprefs));
 
     g_get_charset(&charset);
@@ -1530,7 +1624,7 @@ static gboolean RipNextTrack(GripInfo *ginfo)
       if(ginfo->rippid==0) {
 	CloseStuff(ginfo);
 	nice(ginfo->ripnice);
-	execv(ginfo->ripexename,char_args);
+	execvp(ginfo->ripexename,char_args);
 	
 	LogStatus(ginfo,_("Exec failed\n"));
 	_exit(0);
@@ -1616,7 +1710,7 @@ void FillInTrackInfo(GripInfo *ginfo,int track,EncodeTrack *new_track)
   new_track->end_frame=ginfo->disc.track[track+1].start_frame-1;
 #ifdef CDPAR
   new_track->track_gain_adjustment=ginfo->track_gain_adjustment;
-  new_track->disc_gain_adjustment=ginfo->disc_gain_adjustment;
+  new_track->disc_gain_adjustment=0.0;
 #endif
 
   /* Compensate for the gap before a data track */
@@ -1670,6 +1764,7 @@ static gboolean MP3Encode(GripInfo *ginfo)
   int cpu;
   char *conv_str;
   gsize rb,wb;
+  char *format;
 
   uinfo=&(ginfo->gui_info);
 
@@ -1700,7 +1795,10 @@ static gboolean MP3Encode(GripInfo *ginfo)
 
   str=g_string_new(NULL);
 
-  TranslateString(ginfo->mp3fileformat,str,TranslateSwitch,
+  format = (ginfo->ddata.data_multi_artist)
+                ? ginfo->mp3fileformat_multi
+                : ginfo->mp3fileformat;
+  TranslateString(format,str,TranslateSwitch,
 		  enc_track,TRUE,&(ginfo->sprefs));
 
   conv_str=g_filename_from_utf8(str->str,strlen(str->str),&rb,&wb,NULL);
@@ -1773,7 +1871,7 @@ static gboolean MP3Encode(GripInfo *ginfo)
     CloseStuff(ginfo);
     setsid();
     nice(ginfo->mp3nice);
-    execv(ginfo->mp3exename,char_args);
+    execvp(ginfo->mp3exename,char_args);
     _exit(0);
   }
   else {
